@@ -71,6 +71,33 @@ static void test_aes(const void *data)
 	l_cipher_free(cipher);
 }
 
+static void test_aes_ctr(const void *data)
+{
+	struct l_cipher *cipher;
+	uint8_t iv[8] = { 0 };
+	char buf[256];
+	int r;
+
+	cipher = l_cipher_new(L_CIPHER_AES_CTR, KEY_STR, KEY_LEN);
+	assert(cipher);
+
+	l_cipher_set_iv(cipher, iv, sizeof(iv));
+
+	memcpy(buf, FIXED_STR, FIXED_LEN);
+
+	l_cipher_encrypt(cipher, buf, buf, FIXED_LEN);
+
+	r = memcmp(buf, FIXED_STR, FIXED_LEN);
+	assert(r);
+
+	l_cipher_decrypt(cipher, buf, buf, FIXED_LEN);
+
+	r = memcmp(buf, FIXED_STR, FIXED_LEN);
+	assert(!r);
+
+	l_cipher_free(cipher);
+}
+
 static void test_arc4(const void *data)
 {
 	struct l_cipher *cipher;
@@ -280,7 +307,8 @@ static void test_aead(const void *data)
 	size_t noncelen;
 	uint8_t *nonce = l_util_from_hexstring(tv->nonce, &noncelen);
 	size_t ctlen;
-	uint8_t *ct = l_util_from_hexstring(tv->ciphertext, &ctlen);
+	uint8_t *ct = l_util_from_hexstring(tv->ciphertext, &ctlen) ?:
+		(uint8_t[]) {};
 	size_t taglen;
 	uint8_t *tag = l_util_from_hexstring(tv->tag, &taglen);
 
@@ -317,12 +345,16 @@ static void test_aead(const void *data)
 	assert(!r);
 
 	l_aead_cipher_free(cipher);
+
 	if (ptlen)
 		l_free(pt);
+
 	l_free(key);
 	l_free(aad);
 	l_free(nonce);
-	l_free(ct);
+
+	if (ctlen)
+		l_free(ct);
 	l_free(tag);
 }
 
@@ -335,6 +367,9 @@ int main(int argc, char *argv[])
 	if (l_cipher_is_supported(L_CIPHER_AES))
 		l_test_add("aes", test_aes, NULL);
 
+	if (l_cipher_is_supported(L_CIPHER_AES_CTR))
+		l_test_add("aes_ctr", test_aes_ctr, NULL);
+
 	if (l_cipher_is_supported(L_CIPHER_ARC4))
 		l_test_add("arc4", test_arc4, NULL);
 
